#
# spec file for package tryton
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2015-2018 Dr. Axel Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define majorver 4.6
Name:           tryton
Version:        %{majorver}.21
Release:        lp151.2.3.1
Summary:        The client of the Tryton application platform
License:        GPL-3.0-only
Group:          Productivity/Office/Management
Url:            http://www.tryton.org/
Source:         http://downloads.tryton.org/%{majorver}/%{name}-%{version}.tar.gz
Source1:        ftp://ftp.gnu.org/gnu/health/plugins/gnuhealth-camera-plugin-latest.tar.gz
Patch0:         tryton_crypto.patch
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  python-Babel
BuildRequires:  python-Sphinx
# List of additional build dependencies
BuildRequires:  python-devel
BuildRequires:  python-gtk
BuildRequires:  python-python-dateutil
BuildRequires:  python-setuptools
BuildRequires:  python-simplejson
BuildRequires:  update-desktop-files
Requires:       librsvg
#for the plugins:
Requires:       opencv
Requires:       python-cdecimal
Requires:       python-chardet
Requires:       python-dateutil
Requires:       python-gnupg
Requires:       python-gtk
Requires:       python-opencv
Requires:       python-pytz
Requires:       python-setuptools
Requires:       python-simplejson
Requires:       python-xml
Requires:       python2-GooCalendar
BuildArch:      noarch

%description
The client of the Tryton application platform.
A three-tiers  high-level general purpose application platform
written in Python and use Postgresql as database engine.
It is the core base of an Open Source ERP.
It provides modularity, scalability and security.

%prep
%setup -q
%patch0 -p1
pwd
cd %{name}/plugins/
tar --strip-components 1 -xzvf %{SOURCE1}

%build
:

%install

python setup.py install --prefix=%{_prefix} --root=%{buildroot}

# menu-entry
desktop-file-install --dir %{buildroot}%{_datadir}/applications %{name}.desktop
%suse_update_desktop_file %{name}

%python_expand %fdupes %{buildroot}%{_datadir}
%python_expand %fdupes %{buildroot}%{_prefix}/lib

mkdir -p %{buildroot}%{_datadir}/pixmaps
cp %{buildroot}%{python_sitelib}/%{name}/data/pixmaps/%{name}/%{name}-icon.png %{buildroot}%{_datadir}/pixmaps/%{name}-icon.png

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%doc README CHANGELOG
%license LICENSE COPYRIGHT
%{_datadir}/pixmaps/*
%{python_sitelib}/*

%changelog
* Fri Jul 12 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.21 - Bugfix Release
* Fri May 17 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.19 - Bugfix Release
* Fri Apr  5 2019 Axel Braun <axel.braun@gmx.de>
- version 4.6.18 - security release (boo#1131707)
* Sun Mar 24 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.17 - Bugfix Release
* Wed Feb 20 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.16 - Bugfix Release
* Sun Jan 27 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.15 - Bugfix Release
* Mon Jan  7 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.14 - Bugfix Release
* Tue Nov 13 2018 Axel Braun <axel.braun@gmx.de>
- Version 4.2.19 - Bugfix Release (CVE-2018-19443 boo#1117105)
  License-Macro added
* Mon Sep 24 2018 Axel Braun <axel.braun@gmx.de>
- Version 4.2.18 - Bugfix Release
* Wed Aug 22 2018 axel.braun@gmx.de
- Version 4.2.17 - Bugfix Release (boo#1107771)
* Sat Aug  4 2018 axel.braun@gmx.de
- Version 4.2.16 - Bugfix Release
* Wed Jul 11 2018 axel.braun@gmx.de
- Version 4.2.15 - Bugfix Release
* Tue Jun  5 2018 axel.braun@gmx.de
- Version 4.2.14 - Bugfix Release
* Sat May 12 2018 axel.braun@gmx.de
- Version 4.2.12 - Bugfix Release
* Wed Mar 21 2018 axel.braun@gmx.de
- Version 4.2.11 - Bugfix Release
* Fri Mar  2 2018 axel.braun@gmx.de
- Version 4.2.10 - Bugfix Release
* Mon Jan 29 2018 tchvatal@suse.com
- Do not pull in python-gnome-desktop package
- Add null build phase to make rpmlint happy
* Tue Dec  5 2017 axel.braun@gmx.de
- Version 4.2.9 - Bugfix Release
* Thu Nov  9 2017 axel.braun@gmx.de
- Version 4.2.8 - Bugfix Release
* Wed Oct  4 2017 axel.braun@gmx.de
- Version 4.2.7 - Bugfix Release
* Thu Aug 10 2017 axel.braun@gmx.de
- Version 4.2.6
* Tue Jun  6 2017 axel.braun@gmx.de
- Version 4.2.5
* Fri Mar 10 2017 axel.braun@gmx.de
- Version 4.2.4
* Tue Feb  7 2017 axel.braun@gmx.de
- Version 4.2.3
* Fri Jan  6 2017 axel.braun@gmx.de
- Version 4.2.1
* Mon Nov 28 2016 axel.braun@gmx.de 
- Tryton Release 4.2
* Mon May  2 2016 axel.braun@gmx.de 
- Tryton Release 4.0
* Mon Apr  4 2016 axel.braun@gmx.de
- added GNUHealth Camera and OpenCV
* Thu Nov  5 2015 axel.braun@gmx.de
- Version 3.8.1
  tryton-lang removed
* Mon Oct 19 2015 axel.braun@gmx.de 
- Tryton Release 3.8
* Wed Apr 15 2015 axel.braun@gmx.de 
- Tryton Release 3.6
* Fri Feb  7 2014 axel.braun@gmx.de
- update to 3.0.2, changes to specfile
* Mon Nov 11 2013 axel.braun@gmx.de
- update to 3.0.1, patch for mime type
* Wed Oct 23 2013 axel.braun@gmx.de
- new branch 3.0
* Sat Jun 22 2013 axel.braun@gmx.de
- new spec with regard to systemd
- setup of user tryton if not existing
* Sun Mar 29 2009 axel.braun@gmx.de
- packaged tryton version 1.0.3 using the buildservice spec file wizard
